@@ -1,15 +1,15 @@
+mod argument_attr;
 mod attr_names;
 mod doc_attr;
 mod endpoint_attr;
 mod event_attr;
-mod module_attr;
 mod payable_attr;
 mod storage_attr;
 mod util;
 
-pub use doc_attr::{extract_doc, find_output_names};
+pub use argument_attr::*;
+pub use doc_attr::{extract_doc, OutputNameAttribute};
 pub use endpoint_attr::*;
 pub use event_attr::*;
-pub use module_attr::*;
 pub use payable_attr::*;
 pub use storage_attr::*;
